@@ -35,9 +35,9 @@ import tim.prune.gui.profile.ProfileChart;
 public class GpsPrune
 {
 	/** Version number of application, used in about screen and for version check */
-	public static final String VERSION_NUMBER = "13.1";
+	public static final String VERSION_NUMBER = "13.2";
 	/** Build number, just used for about screen */
-	public static final String BUILD_NUMBER = "244";
+	public static final String BUILD_NUMBER = "244a";
 	/** Static reference to App object */
 	private static App APP = null;
 
@@ -134,13 +134,15 @@ public class GpsPrune
 			// If langfilename is blank on command line parameters then don't use setting from config
 			langFilename = Config.getConfigString(Config.KEY_LANGUAGE_FILE);
 		}
-		if (langFilename != null && !langFilename.equals("")) {
+		if (langFilename != null)
+		{
 			try {
 				I18nManager.addLanguageFile(langFilename);
 				Config.setConfigString(Config.KEY_LANGUAGE_FILE, langFilename);
 			}
 			catch (FileNotFoundException fnfe) {
 				System.err.println("Failed to load language file: " + langFilename);
+				Config.setConfigString(Config.KEY_LANGUAGE_FILE, "");
 			}
 		}
 		// Set up the window and go
