@@ -343,7 +343,9 @@ public class GpxExporter extends GenericFunction implements Runnable
 		if (inUseCopy) gpxCachers = new GpxCacherList(inInfo.getFileInfo());
 		// Write or copy headers
 		inWriter.write(getXmlHeaderString(inWriter));
-		inWriter.write(getGpxHeaderString(gpxCachers));
+		final String gpxHeader = getGpxHeaderString(gpxCachers);
+		final boolean isVersion1_1 = (gpxHeader.toUpperCase().indexOf("GPX/1/1") > 0);
+		inWriter.write(gpxHeader);
 		// Name field
 		String trackName = "GpsPruneTrack";
 		if (inName != null && !inName.equals(""))
@@ -353,10 +355,7 @@ public class GpxExporter extends GenericFunction implements Runnable
 			inWriter.write(trackName);
 			inWriter.write("</name>\n");
 		}
-		// Description field
-		inWriter.write("\t<desc>");
-		inWriter.write((inDesc != null && !inDesc.equals(""))?inDesc:"Export from GpsPrune");
-		inWriter.write("</desc>\n");
+		writeDescription(inWriter, inDesc, isVersion1_1);
 
 		int i = 0;
 		DataPoint point = null;
@@ -414,6 +413,31 @@ public class GpxExporter extends GenericFunction implements Runnable
 	}
 
 
+	/**
+	 * Write the description according to the GPX version number
+	 * @param inWriter writer object
+	 * @param inDesc description, or null if none supplied
+	 * @param inIsVersion1_1 true if gpx version 1.1, false for version 1.0
+	 */
+	private static void writeDescription(OutputStreamWriter inWriter,
+		String inDesc, boolean inIsVersion1_1) throws IOException
+	{
+		String desc = (inDesc != null && !inDesc.equals(""))? inDesc : "Export from GpsPrune";
+		// Position of description field needs to be different for GPX1.0 and GPX1.1
+		if (inIsVersion1_1)
+		{
+			// GPX 1.1 has a creator tag inside a metadata tag
+			inWriter.write("\t<metadata>");
+		}
+		inWriter.write("\t<desc>");
+		inWriter.write(desc);
+		inWriter.write("</desc>\n");
+		if (inIsVersion1_1)
+		{
+			inWriter.write("</metadata>\n");
+		}
+	}
+
 	/**
 	 * Loop through the track outputting the relevant track points
 	 * @param inWriter writer object for output
